"""
Parse confmanager objects in interesting ways.
"""
from confmanager import *

def parse_template(template, target):
 """Given a dictionary template containing at least most of the relevant information and a dictionary target containing sections, options and values, consolidate target into a new confmanager object and return it."""
 c = ConfManager('')
 for section in template:
  c.add_section(section)
  for option, o in template[section].items():
   try:
    value = type(template[section][option]['value'])(target[section][option])
   except KeyError:
    value = o['value']
   finally:
    if 'value' in o:
     del o['value']
   c.set(section, option, value, **o)
 return c

def parse_json(target, json, create_sections = False, create_options = False):
 """Given a confmanager object and a dictionary object, import the values from the dictionary into the object, optionally adding sections and options as it goes."""
 for o in json:
  if not target.has_section(o):
   if create_sections:
    target.add_section(o)
   else:
    continue
  for k, v in json[o].items():
   if target.has_option(o, k) or create_options:
    target.set(o, k, v) # Don't add if it shouldn't be there.
 return target
